@@ -7,11 +7,11 @@
 
 /* .C calls */
 extern void lp_transbig(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
-extern void lpslink(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void lpslink(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 
 static const R_CMethodDef CEntries[] = {
     {"lp_transbig", (DL_FUNC) &lp_transbig, 20},
-    {"lpslink",     (DL_FUNC) &lpslink,     28},
+    {"lpslink",     (DL_FUNC) &lpslink,     29},
     {NULL, NULL, 0}
 };
 
